package com.fastbee.rechargecard.mapper;

import java.util.List;
import com.fastbee.rechargecard.domain.NgIrrigationControllers;
import org.apache.ibatis.annotations.Mapper;

/**
 * 灌溉控制器信息Mapper接口
 *
 * @author kerwincui
 * @date 2024-12-19
 */
@Mapper
public interface NgIrrigationControllersMapper
{
    /**
     * 查询灌溉控制器信息
     *
     * @param id 灌溉控制器信息主键
     * @return 灌溉控制器信息
     */
    public NgIrrigationControllers selectNgIrrigationControllersById(Long id);
    /**
     * 查询灌溉控制器信息
     *
     * @param serialNumber 灌溉控制器编码
     * @return 灌溉控制器信息
     */
    public NgIrrigationControllers selectNgIrrigationControllersBySerialNumber(String serialNumber);

    /**
     * 查询灌溉控制器信息列表
     *
     * @param ngIrrigationControllers 灌溉控制器信息
     * @return 灌溉控制器信息集合
     */
    public List<NgIrrigationControllers> selectNgIrrigationControllersList(NgIrrigationControllers ngIrrigationControllers);

    /**
     * 新增灌溉控制器信息
     *
     * @param ngIrrigationControllers 灌溉控制器信息
     * @return 结果
     */
    public int insertNgIrrigationControllers(NgIrrigationControllers ngIrrigationControllers);

    /**
     * 修改灌溉控制器信息
     *
     * @param ngIrrigationControllers 灌溉控制器信息
     * @return 结果
     */
    public int updateNgIrrigationControllers(NgIrrigationControllers ngIrrigationControllers);

    /**
     * 删除灌溉控制器信息
     *
     * @param id 灌溉控制器信息主键
     * @return 结果
     */
    public int deleteNgIrrigationControllersById(Long id);

    /**
     * 批量删除灌溉控制器信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteNgIrrigationControllersByIds(Long[] ids);
}
